---
last_modified_on: "2020-07-13"
delivery_guarantee: "at_least_once"
component_title: "Datadog Metrics"
description: "The Vector `datadog_metrics` sink batches `metric` events to Datadog's metrics service using HTTP API."
event_types: ["metric"]
function_category: "transmit"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+datadog_metrics%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "datadog_metrics|[\"metric\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sinks/datadog/metrics.rs
status: "beta"
title: "Datadog Metrics Sink"
unsupported_operating_systems: []
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `datadog_metrics` sink
[batches](#buffers--batches) [`metric`][docs.data-model.metric] events to
[Datadog's][urls.datadog] metrics service using [HTTP
API](https://docs.datadoghq.com/api/?lang=bash#metrics).

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sinks/datadog_metrics.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[sinks.my_sink_id]
  type = "datadog_metrics" # required
  inputs = ["my-source-or-transform-id"] # required
  api_key = "${DATADOG_API_KEY}" # required
  healthcheck = true # optional, default
  namespace = "service" # required
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[sinks.my_sink_id]
  # General
  type = "datadog_metrics" # required
  inputs = ["my-source-or-transform-id"] # required
  api_key = "${DATADOG_API_KEY}" # required
  healthcheck = true # optional, default
  host = "https://api.datadoghq.com" # optional, default
  namespace = "service" # required

  # Batch
  batch.max_events = 20 # optional, default, events
  batch.timeout_secs = 1 # optional, default, seconds

  # Request
  request.in_flight_limit = 5 # optional, default, requests
  request.rate_limit_duration_secs = 1 # optional, default, seconds
  request.rate_limit_num = 5 # optional, default
  request.retry_attempts = 18446744073709551615 # optional, default
  request.retry_initial_backoff_secs = 1 # optional, default, seconds
  request.retry_max_duration_secs = 10 # optional, default, seconds
  request.timeout_secs = 60 # optional, default, seconds
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["${DATADOG_API_KEY}","ef8d5de700e7989468166c40fc8a0ccd"]}
  groups={[]}
  name={"api_key"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### api_key

Datadog [API key](https://docs.datadoghq.com/api/?lang=bash#authentication)



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"batch"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### batch

Configures the sink batching behavior.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={20}
  enumValues={null}
  examples={[20]}
  groups={[]}
  name={"max_events"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"events"}
  warnings={[]}
  >

#### max_events

The maximum size of a batch, in events, before it is flushed.



</Field>
<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"timeout_secs"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### timeout_secs

The maximum age of a batch before it is flushed.



</Field>
</Fields>

</Field>
<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"healthcheck"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### healthcheck

Enables/disables the sink healthcheck upon start.
 See [Health Checks](#health-checks) for more info.


</Field>
<Field
  common={false}
  defaultValue={"https://api.datadoghq.com"}
  enumValues={null}
  examples={["https://api.datadoghq.com","https://api.datadoghq.eu"]}
  groups={[]}
  name={"host"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### host

Datadog endpoint to send metrics to.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["service"]}
  groups={[]}
  name={"namespace"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### namespace

A prefix that will be added to all metric names.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"request"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### request

Configures the sink request behavior.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={5}
  enumValues={null}
  examples={[5]}
  groups={[]}
  name={"in_flight_limit"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"requests"}
  warnings={[]}
  >

#### in_flight_limit

The maximum number of in-flight requests allowed at any given time.
 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"rate_limit_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### rate_limit_duration_secs

The time window, in seconds, used for the [`rate_limit_num`](#rate_limit_num) option.
 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={true}
  defaultValue={5}
  enumValues={null}
  examples={[5]}
  groups={[]}
  name={"rate_limit_num"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={null}
  warnings={[]}
  >

#### rate_limit_num

The maximum number of requests allowed within the [`rate_limit_duration_secs`](#rate_limit_duration_secs)
time window.
 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={false}
  defaultValue={18446744073709551615}
  enumValues={null}
  examples={[18446744073709551615]}
  groups={[]}
  name={"retry_attempts"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={null}
  warnings={[]}
  >

#### retry_attempts

The maximum number of retries to make for failed requests. The default, for all
intents and purposes, represents an infinite number of retries.
 See [Retry Policy](#retry-policy) for more info.


</Field>
<Field
  common={false}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"retry_initial_backoff_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### retry_initial_backoff_secs

The amount of time to wait before attempting the first retry for a failed
request. Once, the first retry has failed the fibonacci sequence will be used
to select future backoffs.



</Field>
<Field
  common={false}
  defaultValue={10}
  enumValues={null}
  examples={[10]}
  groups={[]}
  name={"retry_max_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### retry_max_duration_secs

The maximum amount of time, in seconds, to wait between retries.



</Field>
<Field
  common={true}
  defaultValue={60}
  enumValues={null}
  examples={[60]}
  groups={[]}
  name={"timeout_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### timeout_secs

The maximum time a request can take before being aborted. It is highly
recommended that you do not lower value below the service's internal timeout,
as this could create orphaned requests, pile on retries, and result in
duplicate data downstream.



</Field>
</Fields>

</Field>
</Fields>


## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Health Checks

Health checks ensure that the downstream service is accessible and ready to
accept data. This check is performed upon sink initialization.
If the health check fails an error will be logged and Vector will proceed to
start.

#### Require Health Checks

If you'd like to exit immediately upon a health check failure, you can
pass the `--require-healthy` flag:

```bash
vector --config /etc/vector/vector.toml --require-healthy
```

#### Disable Health Checks

If you'd like to disable health checks for this sink you can set the
`healthcheck` option to `false`.

### Metric Types

Datadog accepts the following types for [submission via API](https://docs.datadoghq.com/developers/metrics/#submission-types-and-datadog-in-app-types):

* Count
* Gauge
* Rate

The following matrix outlines how Vector metric types are mapped into Datadog metrics types.

| Vector Metrics | Datadog Metrics |
|----------------|-----------------|
| Counter        | Count           |
| Gauge          | Gauge           |
| Gauge Delta    | N/A             |
| Histogram      | Count [1]       |
| Set            | N/A             |

1. Aggregation of Histogram values is not supported at the moment. Histogram values will be sent as is, as raw Count values.

### Rate Limits

Vector offers a few levers to control the rate and volume of requests to the
downstream service. Start with the [`rate_limit_duration_secs`](#rate_limit_duration_secs) and
`rate_limit_num` options to ensure Vector does not exceed the specified
number of requests in the specified window. You can further control the pace at
which this window is saturated with the [`in_flight_limit`](#in_flight_limit) option, which
will guarantee no more than the specified number of requests are in-flight at
any given time.

Please note, Vector's defaults are carefully chosen and it should be rare that
you need to adjust these. If you found a good reason to do so please share it
with the Vector team by [opening an issue][urls.new_datadog_metrics_sink_issue].

### Retry Policy

Vector will retry failed requests (status == `429`, >= `500`, and != `501`).
Other responses will _not_ be retried. You can control the number of retry
attempts and backoff rate with the [`retry_attempts`](#retry_attempts) and
`retry_backoff_secs` options.

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.metric]: /docs/about/data-model/metric/
[urls.datadog]: https://www.datadoghq.com
[urls.new_datadog_metrics_sink_issue]: https://github.com/timberio/vector/issues/new?labels=sink%3A+datadog_metrics
