---
last_modified_on: "2020-07-13"
delivery_guarantee: "at_least_once"
component_title: "GCP Stackdriver Logs"
description: "The Vector `gcp_stackdriver_logs` sink batches [`log`](#log) events to Google Cloud Platform's Stackdriver Logging service via the REST Interface."
event_types: ["log"]
function_category: "transmit"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+gcp_stackdriver_logs%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "gcp_stackdriver_logs|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sinks/gcp/stackdriver_logs.rs
status: "beta"
title: "GCP Stackdriver Logs Sink"
unsupported_operating_systems: []
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import SVG from 'react-inlinesvg';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `gcp_stackdriver_logs` sink
[batches](#buffers--batches) [`log`][docs.data-model.log] events to [Google
Cloud Platform's Stackdriver Logging service][urls.gcp_stackdriver_logging] via
the [REST Interface][urls.gcp_stackdriver_logging_rest].

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sinks/gcp_stackdriver_logs.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[sinks.my_sink_id]
  type = "gcp_stackdriver_logs" # required
  inputs = ["my-source-or-transform-id"] # required
  credentials_path = "/path/to/credentials.json" # optional, no default
  healthcheck = true # optional, default
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[sinks.my_sink_id]
  # General
  type = "gcp_stackdriver_logs" # required
  inputs = ["my-source-or-transform-id"] # required
  billing_account_id = "012345-6789AB-CDEF01" # optional, no default
  credentials_path = "/path/to/credentials.json" # optional, no default
  folder_id = "My Folder" # optional, no default
  healthcheck = true # optional, default
  log_id = "vector-logs" # required
  organization_id = "622418129737" # optional, no default
  project_id = "vector-123456" # required
  severity_key = "severity" # optional, no default

  # Batch
  batch.max_bytes = 5242880 # optional, default, bytes
  batch.max_events = 1000 # optional, no default, events
  batch.timeout_secs = 1 # optional, default, seconds

  # Buffer
  buffer.max_events = 500 # optional, default, events, relevant when type = "memory"
  buffer.max_size = 104900000 # required, bytes, required when type = "disk"
  buffer.type = "memory" # optional, default
  buffer.when_full = "block" # optional, default

  # Encoding
  encoding.except_fields = ["timestamp", "message", "host"] # optional, no default
  encoding.only_fields = ["timestamp", "message", "host"] # optional, no default
  encoding.timestamp_format = "rfc3339" # optional, default

  # Request
  request.in_flight_limit = 5 # optional, default, requests
  request.rate_limit_duration_secs = 1 # optional, default, seconds
  request.rate_limit_num = 1000 # optional, default
  request.retry_attempts = 18446744073709551615 # optional, default
  request.retry_initial_backoff_secs = 1 # optional, default, seconds
  request.retry_max_duration_secs = 10 # optional, default, seconds
  request.timeout_secs = 60 # optional, default, seconds

  # Resource
  resource.type = "global" # required
  resource.projectId = "vector-123456" # example
  resource.zone = "Twilight" # example

  # TLS
  tls.ca_file = "/path/to/certificate_authority.crt" # optional, no default
  tls.crt_file = "/path/to/host_certificate.crt" # optional, no default
  tls.key_file = "/path/to/host_certificate.key" # optional, no default
  tls.key_pass = "${KEY_PASS_ENV_VAR}" # optional, no default
  tls.verify_certificate = true # optional, default
  tls.verify_hostname = true # optional, default
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"batch"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### batch

Configures the sink batching behavior.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={5242880}
  enumValues={null}
  examples={[5242880]}
  groups={[]}
  name={"max_bytes"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"bytes"}
  warnings={[]}
  >

#### max_bytes

The maximum size of a batch, in bytes, before it is flushed.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[1000]}
  groups={[]}
  name={"max_events"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"events"}
  warnings={[]}
  >

#### max_events

The maximum size of a batch, in events, before it is flushed.
 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"timeout_secs"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### timeout_secs

The maximum age of a batch before it is flushed.
 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["012345-6789AB-CDEF01"]}
  groups={[]}
  name={"billing_account_id"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### billing_account_id

The billing account ID to which to publish logs.

Exactly one of [`billing_account_id`](#billing_account_id), [`folder_id`](#folder_id), [`organization_id`](#organization_id), or
`project_id` must be set.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"buffer"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### buffer

Configures the sink specific buffer behavior.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={500}
  enumValues={null}
  examples={[500]}
  groups={[]}
  name={"max_events"}
  path={"buffer"}
  relevantWhen={{"type":"memory"}}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"events"}
  warnings={[]}
  >

#### max_events

The maximum number of [events][docs.data-model] allowed in the buffer.
 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[104900000]}
  groups={[]}
  name={"max_size"}
  path={"buffer"}
  relevantWhen={{"type":"disk"}}
  required={true}
  templateable={false}
  type={"uint"}
  unit={"bytes"}
  warnings={[]}
  >

#### max_size

The maximum size of the buffer on the disk.



</Field>
<Field
  common={true}
  defaultValue={"memory"}
  enumValues={{"memory":"Stores the sink's buffer in memory. This is more performant, but less durable. Data will be lost if Vector is restarted forcefully.","disk":"Stores the sink's buffer on disk. This is less performant, but durable. Data will not be lost between restarts."}}
  examples={["memory","disk"]}
  groups={[]}
  name={"type"}
  path={"buffer"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### type

The buffer's type and storage mechanism.



</Field>
<Field
  common={false}
  defaultValue={"block"}
  enumValues={{"block":"Applies back pressure when the buffer is full. This prevents data loss, but will cause data to pile up on the edge.","drop_newest":"Drops new data as it's received. This data is lost. This should be used when performance is the highest priority."}}
  examples={["block","drop_newest"]}
  groups={[]}
  name={"when_full"}
  path={"buffer"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### when_full

The behavior when the buffer becomes full.



</Field>
</Fields>

</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/credentials.json"]}
  groups={[]}
  name={"credentials_path"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### credentials_path

The filename for a Google Cloud service account credentials JSON file used to
authenticate access to the Stackdriver Logging API. If this is unset, Vector
checks the [`GOOGLE_APPLICATION_CREDENTIALS`](#google_application_credentials) environment variable for a filename.

If no filename is named, Vector will attempt to fetch an instance service
account for the compute instance the program is running on. If Vector is not
running on a GCE instance, you must define a credentials file as above.
 See [GCP Authentication](#gcp-authentication) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"encoding"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### encoding

Configures the encoding specific sink behavior.


<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[["timestamp","message","host"]]}
  groups={[]}
  name={"except_fields"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

#### except_fields

Prevent the sink from encoding the specified labels.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[["timestamp","message","host"]]}
  groups={[]}
  name={"only_fields"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

#### only_fields

Limit the sink to only encoding the specified labels.



</Field>
<Field
  common={false}
  defaultValue={"rfc3339"}
  enumValues={{"rfc3339":"Format as an RFC3339 string","unix":"Format as a unix timestamp, can be parsed as a Clickhouse DateTime"}}
  examples={["rfc3339","unix"]}
  groups={[]}
  name={"timestamp_format"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### timestamp_format

How to format event timestamps.



</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["My Folder"]}
  groups={[]}
  name={"folder_id"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### folder_id

The folder ID to which to publish logs.
See the [Google Cloud Platform folder documentation][urls.gcp_folders] for more
details.

Exactly one of [`billing_account_id`](#billing_account_id), [`folder_id`](#folder_id), [`organization_id`](#organization_id), or
`project_id` must be set.



</Field>
<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"healthcheck"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### healthcheck

Enables/disables the sink healthcheck upon start.
 See [Health Checks](#health-checks) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["vector-logs"]}
  groups={[]}
  name={"log_id"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### log_id

The log ID to which to publish logs. This is a name you create to identify this
log stream.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["622418129737"]}
  groups={[]}
  name={"organization_id"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### organization_id

The organization ID to which to publish logs. This would be the identifier
assigned to your organization on Google Cloud Platform.

Exactly one of [`billing_account_id`](#billing_account_id), [`folder_id`](#folder_id), [`organization_id`](#organization_id), or
`project_id` must be set.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["vector-123456"]}
  groups={[]}
  name={"project_id"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### project_id

The project ID to which to publish logs. See the [Google Cloud Platform project
management documentation][urls.gcp_projects] for more details.

Exactly one of [`billing_account_id`](#billing_account_id), [`folder_id`](#folder_id), [`organization_id`](#organization_id), or
`project_id` must be set.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"request"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### request

Configures the sink request behavior.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={5}
  enumValues={null}
  examples={[5]}
  groups={[]}
  name={"in_flight_limit"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"requests"}
  warnings={[]}
  >

#### in_flight_limit

The maximum number of in-flight requests allowed at any given time.
 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"rate_limit_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### rate_limit_duration_secs

The time window, in seconds, used for the [`rate_limit_num`](#rate_limit_num) option.
 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={true}
  defaultValue={1000}
  enumValues={null}
  examples={[1000]}
  groups={[]}
  name={"rate_limit_num"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={null}
  warnings={[]}
  >

#### rate_limit_num

The maximum number of requests allowed within the [`rate_limit_duration_secs`](#rate_limit_duration_secs)
time window.
 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={false}
  defaultValue={18446744073709551615}
  enumValues={null}
  examples={[18446744073709551615]}
  groups={[]}
  name={"retry_attempts"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={null}
  warnings={[]}
  >

#### retry_attempts

The maximum number of retries to make for failed requests. The default, for all
intents and purposes, represents an infinite number of retries.
 See [Retry Policy](#retry-policy) for more info.


</Field>
<Field
  common={false}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"retry_initial_backoff_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### retry_initial_backoff_secs

The amount of time to wait before attempting the first retry for a failed
request. Once, the first retry has failed the fibonacci sequence will be used
to select future backoffs.



</Field>
<Field
  common={false}
  defaultValue={10}
  enumValues={null}
  examples={[10]}
  groups={[]}
  name={"retry_max_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### retry_max_duration_secs

The maximum amount of time, in seconds, to wait between retries.



</Field>
<Field
  common={true}
  defaultValue={60}
  enumValues={null}
  examples={[60]}
  groups={[]}
  name={"timeout_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### timeout_secs

The maximum time a request can take before being aborted. It is highly
recommended that you do not lower value below the service's internal timeout,
as this could create orphaned requests, pile on retries, and result in
duplicate data downstream.
 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"resource"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### resource

Options for describing the logging resource.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["global","gce_instance"]}
  groups={[]}
  name={"type"}
  path={"resource"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### type

The monitored resource type. For example, the type of a Compute Engine VM
instance is gce_instance.

See the [Google Cloud Platform monitored resource
documentation][urls.gcp_resources] for more details.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[{"projectId":"vector-123456"},{"zone":"Twilight"}]}
  groups={[]}
  name={"`[label]`"}
  path={"resource"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### `[label]`

Values for all of the labels listed in the associated monitored resource
descriptor.

For example, Compute Engine VM instances use the labels `projectId`,
`instanceId`, and `zone`.



</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["severity"]}
  groups={[]}
  name={"severity_key"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### severity_key

The field of the log event from which to take the outgoing log's [`severity`](#severity)
field. The named field is removed from the log event if present, and must be
either an integer between 0 and 800 or a string containing one of the [severity
level names][urls.gcp_stackdriver_severity] (case is ignored) or a common
prefix such as `err`. This could be added by an [`add_fields`
transform][docs.transforms.add_fields] or extracted from a field from the
source.

If no severity key is specified, the severity of outgoing records will be set
to 0 (`DEFAULT`).

See the [GCP Stackdriver Logging LogSeverity
description][urls.gcp_stackdriver_severity] for more details on the value of
the [`severity`](#severity) field.
 See [Severity Level Remapping](#severity-level-remapping) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"tls"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### tls

Configures the TLS options for connections from this sink.


<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/certificate_authority.crt"]}
  groups={[]}
  name={"ca_file"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### ca_file

Absolute path to an additional CA certificate file, in DER or PEM format
(X.509), or an inline CA certificate in PEM format.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.crt"]}
  groups={[]}
  name={"crt_file"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### crt_file

Absolute path to a certificate file used to identify this connection, in DER or
PEM format (X.509) or PKCS#12, or an inline certificate in PEM format. If this
is set and is not a PKCS#12 archive, [`key_file`](#key_file) must also be set.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.key"]}
  groups={[]}
  name={"key_file"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### key_file

Absolute path to a private key file used to identify this connection, in DER or
PEM format (PKCS#8), or an inline private key in PEM format. If this is set,
`crt_file` must also be set.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["${KEY_PASS_ENV_VAR}","PassWord1"]}
  groups={[]}
  name={"key_pass"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### key_pass

Pass phrase used to unlock the encrypted key file. This has no effect unless
`key_file` is set.



</Field>
<Field
  common={false}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"verify_certificate"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[{"visibility_level":"option","text":"Setting this to `false` means the certificate will be loaded and checked for validity, but the handshake will not attempt to verify the certificate. Do NOT set this to `false` unless you understand the risks of not verifying the remote certificate.","option_name":"verify_certificate"}]}
  >

#### verify_certificate

If `true` (the default), Vector will validate the TLS certificate of the remote
host.



</Field>
<Field
  common={false}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"verify_hostname"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

#### verify_hostname

If `true` (the default), Vector will validate the configured remote host name
against the remote host's TLS certificate. Do NOT set this to `false` unless
you understand the risks of not verifying the remote hostname.



</Field>
</Fields>

</Field>
</Fields>

## Env Vars

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/credentials.json"]}
  groups={[]}
  name={"GOOGLE_APPLICATION_CREDENTIALS"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### GOOGLE_APPLICATION_CREDENTIALS

The filename for a Google Cloud service account credentials JSON file used to
authenticate access to the Stackdriver Logging API.
 See [GCP Authentication](#gcp-authentication) for more info.


</Field>
</Fields>

## How It Works

### Buffers & Batches

<SVG src="/img/buffers-and-batches-serial.svg" />

The `gcp_stackdriver_logs` sink buffers & batches data as
shown in the diagram above. You'll notice that Vector treats these concepts
differently, instead of treating them as global concepts, Vector treats them
as sink specific concepts. This isolates sinks, ensuring services disruptions
are contained and [delivery guarantees][docs.guarantees] are honored.

*Batches* are flushed when 1 of 2 conditions are met:

1. The batch age meets or exceeds the configured [`timeout_secs`](#timeout_secs).
2. The batch size meets or exceeds the configured [`max_events`](#max_events).

*Buffers* are controlled via the [`buffer.*`](#buffer) options.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### GCP Authentication

GCP offers a [variety of authentication methods][urls.gcp_authentication] and
Vector is concerned with the [server to server methods][urls.gcp_authentication_server_to_server]
and will find credentials in the following order:

1. If the [`credentials_path`](#credentials_path) option is set.
1. If the [`GOOGLE_APPLICATION_CREDENTIALS`](#google_application_credentials) envrionment variable is set.
1. Finally, Vector will check for an [instance service account][urls.gcp_authentication_service_account].

If credentials are not found the [healtcheck](#healthchecks) will fail and an
error will be [logged][docs.monitoring#logs].


### Health Checks

Health checks ensure that the downstream service is accessible and ready to
accept data. This check is performed upon sink initialization.
If the health check fails an error will be logged and Vector will proceed to
start.

#### Require Health Checks

If you'd like to exit immediately upon a health check failure, you can
pass the `--require-healthy` flag:

```bash
vector --config /etc/vector/vector.toml --require-healthy
```

#### Disable Health Checks

If you'd like to disable health checks for this sink you can set the
`healthcheck` option to `false`.

### Rate Limits

Vector offers a few levers to control the rate and volume of requests to the
downstream service. Start with the [`rate_limit_duration_secs`](#rate_limit_duration_secs) and
`rate_limit_num` options to ensure Vector does not exceed the specified
number of requests in the specified window. You can further control the pace at
which this window is saturated with the [`in_flight_limit`](#in_flight_limit) option, which
will guarantee no more than the specified number of requests are in-flight at
any given time.

Please note, Vector's defaults are carefully chosen and it should be rare that
you need to adjust these. If you found a good reason to do so please share it
with the Vector team by [opening an issue][urls.new_gcp_stackdriver_logs_sink_issue].

### Retry Policy

Vector will retry failed requests (status == `429`, >= `500`, and != `501`).
Other responses will _not_ be retried. You can control the number of retry
attempts and backoff rate with the [`retry_attempts`](#retry_attempts) and
`retry_backoff_secs` options.

### Severity Level Remapping

If a [`severity_key`](#severity_key) is configured, outgoing log records will have their
`severity` header field set from the named field in the Vector
event. However, the [required values][urls.gcp_stackdriver_severity] for
this field may be inconvenient to produce, typically requiring a custom
mapping using an additional transform. To assist with this, this sink
remaps certain commonly used words to the required numbers as in the
following table. Note that only the prefix is compared (such that a
value of `emergency` matches `emerg`), and the comparison ignores case.

| Prefix | Value
|:-------|:-----
| emerg  | 800
| fatal  | 800
| alert  | 700
| crit   | 600
| err    | 500
| warn   | 400
| notice | 300
| info   | 200
| debug  | 100
| trace  | 100

### TLS

Vector uses [Openssl][urls.openssl] for TLS protocols for it's battle-tested
and reliable security. You can enable and adjust TLS behavior via the [`tls.*`](#tls)
options.

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.data-model]: /docs/about/data-model/
[docs.guarantees]: /docs/about/guarantees/
[docs.monitoring#logs]: /docs/administration/monitoring/#logs
[docs.transforms.add_fields]: /docs/reference/transforms/add_fields/
[urls.gcp_authentication]: https://cloud.google.com/docs/authentication/
[urls.gcp_authentication_server_to_server]: https://cloud.google.com/docs/authentication/production
[urls.gcp_authentication_service_account]: https://cloud.google.com/docs/authentication/production#obtaining_and_providing_service_account_credentials_manually
[urls.gcp_folders]: https://cloud.google.com/resource-manager/docs/creating-managing-folders
[urls.gcp_projects]: https://cloud.google.com/resource-manager/docs/creating-managing-projects
[urls.gcp_resources]: https://cloud.google.com/monitoring/api/resources
[urls.gcp_stackdriver_logging]: https://cloud.google.com/logging/docs/reference/v2/rest/
[urls.gcp_stackdriver_logging_rest]: https://cloud.google.com/logging/
[urls.gcp_stackdriver_severity]: https://cloud.google.com/logging/docs/reference/v2/rest/v2/LogEntry#logseverity
[urls.new_gcp_stackdriver_logs_sink_issue]: https://github.com/timberio/vector/issues/new?labels=sink%3A+gcp_stackdriver_logs
[urls.openssl]: https://www.openssl.org/
