---
last_modified_on: "2020-07-13"
component_title: "Rename Fields"
description: "The Vector `rename_fields` transform accepts and outputs `log` events, allowing you to rename one or more log fields."
event_types: ["log"]
function_category: "schema"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+rename_fields%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "rename_fields|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/rename_fields.rs
status: "prod-ready"
title: "Rename Fields Transform"
unsupported_operating_systems: []
---

import Alert from '@site/src/components/Alert';
import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `rename_fields` transform
accepts and outputs [`log`][docs.data-model.log] events, allowing you to rename
one or more log fields.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/rename_fields.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "rename_fields" # required
  inputs = ["my-source-or-transform-id"] # required

  # Fields
  fields.old_field_name = "new_field_name" # example
  fields.parent.old_child_name = "parent.new_child_name" # example
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "rename_fields" # required
  inputs = ["my-source-or-transform-id"] # required
  drop_empty = false # optional, default

  # Fields
  fields.old_field_name = "new_field_name" # example
  fields.parent.old_child_name = "parent.new_child_name" # example
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={false}
  defaultValue={false}
  enumValues={null}
  examples={[false,true]}
  groups={[]}
  name={"drop_empty"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### drop_empty

If set to `true`, after renaming fields, remove any parent objects of the old
field that are now empty.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"fields"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### fields

A table of old-key/new-key pairs representing the keys to be moved in the event.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[{"old_field_name":"new_field_name"},{"parent":{"old_child_name":"parent.new_child_name"}}]}
  groups={[]}
  name={"`[field-name]`"}
  path={"fields"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"*"}
  unit={null}
  warnings={[]}
  >

#### `[field-name]`

Old-key/New-key pair reprsenting the key to be moved.



</Field>
</Fields>

</Field>
</Fields>

## Examples

Given the following `log` event:

```js
{
  // ...
  "old_field": "root_value",
  "old_nested": {
    "nested": "nested_value"
  }
  // ...
}
```

And a Vector configuration like:

```toml title="vector.toml"
[transforms.my_transform]
  type = "rename_fields"
  inputs = [...]

  fields.old_field = "new_field"
  fields.old_nested.nested = "new_nested.nested",
```

Will result in the following `log` event:

```js
{
  // ...
  "new_field": "root_value",
  "new_nested": {
    "nested": "nested_value"
  }
  // ...
}
```

## How It Works

### Complex Processing

If you encounter limitations with the `rename_fields`
transform then we recommend using a [runtime transform][urls.vector_programmable_transforms].
These transforms are designed for complex processing and give you the power of
full programming runtime.

### Conflicts

#### Key Conflicts

Keys specified in this transform will replace existing keys.

<Alert type="warning">

Please note. Vector makes no guarantee on the order of execution. If two rename
operations must be performed in a specific order, it is recommended to split
them up across two separate rename transforms.

</Alert>

#### Nested Key Conflicts

Keys are renamed in a deep fashion. They will not replace any ancestor
objects. For example, given the following `log` event:

```javascript
{
  "root": "value2",
  "parent": {
    "child1": "value1"
  }
}
```

And the following configuration:

```toml
[transforms.rename_nested_field]
  type = "rename_fields"
  fields.root = "parent.child2"
```

Will result in the following log event:

```javascript
{
  "parent": {
    "child1": "value1",
    "child2": "value2"
  }
}
```

Notice that `parent.child1` field was preserved.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[urls.vector_programmable_transforms]: https://vector.dev/components/?functions%5B%5D=program
