---
last_modified_on: "2020-07-13"
component_title: "Sampler"
description: "The Vector `sampler` transform accepts and outputs `log` events, allowing you to sample events with a configurable rate."
event_types: ["log"]
function_category: "filter"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+sampler%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "sampler|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/sampler.rs
status: "beta"
title: "Sampler Transform"
unsupported_operating_systems: []
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `sampler` transform
accepts and outputs [`log`][docs.data-model.log] events, allowing you to sample
events with a configurable rate.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/sampler.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  type = "sampler" # required
  inputs = ["my-source-or-transform-id"] # required
  pass_list = ["[error]", "field2"] # optional, no default
  rate = 10 # required
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  type = "sampler" # required
  inputs = ["my-source-or-transform-id"] # required
  key_field = "message" # optional, no default
  pass_list = ["[error]", "field2"] # optional, no default
  rate = 10 # required
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["message"]}
  groups={[]}
  name={"key_field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### key_field

The name of the log field to use to determine if the event should be passed.
This defaults to the [global `message_key`
option][docs.reference.global-options#message_key].



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[["[error]","field2"]]}
  groups={[]}
  name={"pass_list"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

### pass_list

A list of regular expression patterns to exclude events from sampling. If an
event's key field (see [`key_field`](#key_field)) matches _any_ of these patterns it will
_not_ be sampled.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[10]}
  groups={[]}
  name={"rate"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"uint"}
  unit={null}
  warnings={[]}
  >

### rate

The rate at which events will be forwarded, expressed as 1/N. For example,
`rate = 10` means 1 out of every 10 events will be forwarded and the rest will
be dropped.



</Field>
</Fields>

## How It Works

### Complex Processing

If you encounter limitations with the `sampler`
transform then we recommend using a [runtime transform][urls.vector_programmable_transforms].
These transforms are designed for complex processing and give you the power of
full programming runtime.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.reference.global-options#message_key]: /docs/reference/global-options/#message_key
[urls.vector_programmable_transforms]: https://vector.dev/components/?functions%5B%5D=program
